from prettyqt.qt import QtCore


class ItemSelection(QtCore.QItemSelection):
    pass
